import tailwindcss from "@tailwindcss/vite";

export default defineNuxtConfig({
  compatibilityDate: "2024-11-01",
  devtools: { enabled: false },
  // app: {
  //   pageTransition: { name: "page", mode: "out-in" },
  // },
  nitro: {
    routeRules: {
      "/api/**": {
        proxy: {
          to: `${process.env.POCKETBASE_URL || "http://127.0.0.1:8090"}/api/**`,
        },
      },
    },
  },

  modules: ["@pinia/nuxt", "@nuxt/eslint", "@nuxt/ui", "@nuxtjs/i18n", "@pinia/nuxt"],

  i18n: {
    locales: [
      { code: "pl", name: "Pl", icon: "circle-flags:pl" },
      { code: "en", name: "EN", icon: "circle-flags:gb" },
      { code: "cs", name: "CZR", icon: "circle-flags:cz" }
    ],
    lazy: true,
    defaultLocale: "en",
    strategy: "prefix",
    bundle: {
      optimizeTranslationDirective: false,
    },
  },
  css: ["@/assets/fonts.css", "@/assets/main.css"],
  vite: {
    plugins: [tailwindcss()],
    build: {
      sourcemap: false,
    },
    server: {
      allowedHosts: ["arina.ma-al.pl", "marek.ma-al.pl"],
      watch: {
        ignored: ["**/backend/pb_data/**"],
      },
    },
  },
  typescript: {
    tsConfig: {
      compilerOptions: {
        typeRoots: ["./types", "./node_modules/@types"],
      },
      include: ["./types"],
    },
  },
  ui: {},
  icon: {
    localApiEndpoint: "/___nuxt_icon",
  },
});
